@@ -1,5 +1,5 @@
 package OpenSocialX::Shindig::Crypter;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # ABSTRACT: OpenSocial Shindig Crypter
 
@@ -150,7 +150,7 @@ OpenSocialX::Shindig::Crypter - OpenSocial Shindig Crypter
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -249,6 +249,28 @@ decrypt the above data
 
 =back
 
+=head2 EXAMPLE
+
+    use URI::Escape;
+    use MIME::Base64;
+    use OpenSocialX::Shindig::Crypter;
+
+    my $crypter = OpenSocialX::Shindig::Crypter->new( {
+        cipher => $config->{opensocial}->{cipherKey},
+        hmac   => $config->{opensocial}->{hmacKey},
+        iv     => $config->{opensocial}->{ivKey},
+    } );
+    my $security_token = uri_escape( encode_base64( $crypter->create_token( {
+        owner   => $owner_id,
+        viewer  => $viwer_id,
+        app     => $gadget->{id},
+        domain  => $config->{opensocial}->{container},
+        app_url => $gadget->{url},
+    } ) ) );
+
+    # later in tt2 or others
+    # st=$security_token
+
 =head1 AUTHOR
 
   Fayland Lam <fayland@gmail.com>
